Crate mega_system_contracts

Crate mega_system_contracts 

System contracts for the MegaETH EVM.

This crate provides bytecode constants for system contracts used by mega-evm. When building from the repository with Foundry installed, the build script validates that the pre-generated constants match the compiled Solidity source. When building from a published crate (without Foundry), the pre-generated constants are used directly.

Re-exports

pub use alloy_primitives;

Modules

access_control
MegaAccessControl contract bytecode and interface.
keyless_deploy
KeylessDeploy contract bytecode and interface.
limit_control
MegaLimitControl contract bytecode and interface.
oracle
Oracle contract bytecode and interface.
sequencer_registry
SequencerRegistry contract bytecode and interface.