pub struct VolatileDataAccessDisabled {
pub accessType: <VolatileDataAccessType as SolType>::RustType,
}Expand description
@notice Volatile data access was attempted in a frame where it is disabled.
@param accessType The type of volatile data that was accessed.
Custom error with signature VolatileDataAccessDisabled(uint8) and selector 0x09416ebd.
error VolatileDataAccessDisabled(VolatileDataAccessType accessType);Fields
accessType: <VolatileDataAccessType as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for VolatileDataAccessDisabled
impl Clone for VolatileDataAccessDisabled
Sourcefn clone(&self) -> VolatileDataAccessDisabled
fn clone(&self) -> VolatileDataAccessDisabled
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for VolatileDataAccessDisabled
impl Debug for VolatileDataAccessDisabled
impl Eq for VolatileDataAccessDisabled
Sourceimpl Hash for VolatileDataAccessDisabled
impl Hash for VolatileDataAccessDisabled
Sourceimpl PartialEq for VolatileDataAccessDisabled
impl PartialEq for VolatileDataAccessDisabled
Sourcefn eq(&self, other: &VolatileDataAccessDisabled) -> bool
fn eq(&self, other: &VolatileDataAccessDisabled) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolError for VolatileDataAccessDisabled
impl SolError for VolatileDataAccessDisabled
Sourceconst SIGNATURE: &'static str = "VolatileDataAccessDisabled(uint8)"
const SIGNATURE: &'static str = "VolatileDataAccessDisabled(uint8)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (VolatileDataAccessType,)
type Parameters<'a> = (VolatileDataAccessType,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<VolatileDataAccessDisabled as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<VolatileDataAccessDisabled as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl StructuralPartialEq for VolatileDataAccessDisabled