pub struct disableVolatileDataAccessCall;Expand description
@notice Disables volatile data access for the caller’s frame and all inner calls.
@dev When called, the caller’s own frame and any inner
CALL/STATICCALL/DELEGATECALL/CALLCODE that accesses volatile data
(block env fields, beneficiary balance, oracle) will revert with
VolatileDataAccessDisabled().
Available from Rex4 hardfork.
Function with signature disableVolatileDataAccess() and selector 0xc62e8daf.
function disableVolatileDataAccess() external view;Trait Implementations
Sourceimpl Clone for disableVolatileDataAccessCall
impl Clone for disableVolatileDataAccessCall
Sourcefn clone(&self) -> disableVolatileDataAccessCall
fn clone(&self) -> disableVolatileDataAccessCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for disableVolatileDataAccessCall
impl Default for disableVolatileDataAccessCall
Sourcefn default() -> disableVolatileDataAccessCall
fn default() -> disableVolatileDataAccessCall
Returns the “default value” for a type. Read more
impl Eq for disableVolatileDataAccessCall
Sourceimpl Hash for disableVolatileDataAccessCall
impl Hash for disableVolatileDataAccessCall
Sourceimpl PartialEq for disableVolatileDataAccessCall
impl PartialEq for disableVolatileDataAccessCall
Sourcefn eq(&self, other: &disableVolatileDataAccessCall) -> bool
fn eq(&self, other: &disableVolatileDataAccessCall) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl SolCall for disableVolatileDataAccessCall
impl SolCall for disableVolatileDataAccessCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<disableVolatileDataAccessCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<disableVolatileDataAccessCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = disableVolatileDataAccessReturn
type Return = disableVolatileDataAccessReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<disableVolatileDataAccessCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<disableVolatileDataAccessCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for disableVolatileDataAccessCall