pub struct enableVolatileDataAccessReturn {}Expand description
@notice Re-enables volatile data access for the caller’s frame and inner calls.
@dev Succeeds if access is not disabled, or the caller (or an ancestor at the
same depth) disabled it. Reverts with DisabledByParent() if a parent
frame disabled access.
Available from Rex4 hardfork.
Container type for the return parameters of the enableVolatileDataAccess() function.