pub enum IKeylessDeployErrors {
Show 22 variants
MalformedEncoding(MalformedEncoding),
NotContractCreation(NotContractCreation),
NotPreEIP155(NotPreEIP155),
NonZeroTxNonce(NonZeroTxNonce),
NoEtherTransfer(NoEtherTransfer),
InvalidSignature(InvalidSignature),
InsufficientBalance(InsufficientBalance),
ContractAlreadyExists(ContractAlreadyExists),
SignerNonceTooHigh(SignerNonceTooHigh),
ExecutionReverted(ExecutionReverted),
ExecutionHalted(ExecutionHalted),
ParentBudgetExceeded(ParentBudgetExceeded),
EmptyCodeDeployed(EmptyCodeDeployed),
NoContractCreated(NoContractCreated),
AddressMismatch(AddressMismatch),
GasLimitTooLow(GasLimitTooLow),
InsufficientComputeGas(InsufficientComputeGas),
InitCodeTooLarge(InitCodeTooLarge),
SignerHasCode(SignerHasCode),
InternalError(InternalError),
InvalidTransaction(InvalidTransaction),
NotIntercepted(NotIntercepted),
}Expand description
Container for all the IKeylessDeploy custom errors.
Variants
MalformedEncoding(MalformedEncoding)
NotContractCreation(NotContractCreation)
NotPreEIP155(NotPreEIP155)
NonZeroTxNonce(NonZeroTxNonce)
NoEtherTransfer(NoEtherTransfer)
InvalidSignature(InvalidSignature)
InsufficientBalance(InsufficientBalance)
ContractAlreadyExists(ContractAlreadyExists)
SignerNonceTooHigh(SignerNonceTooHigh)
ExecutionReverted(ExecutionReverted)
ExecutionHalted(ExecutionHalted)
ParentBudgetExceeded(ParentBudgetExceeded)
EmptyCodeDeployed(EmptyCodeDeployed)
NoContractCreated(NoContractCreated)
AddressMismatch(AddressMismatch)
GasLimitTooLow(GasLimitTooLow)
InsufficientComputeGas(InsufficientComputeGas)
InitCodeTooLarge(InitCodeTooLarge)
SignerHasCode(SignerHasCode)
InternalError(InternalError)
InvalidTransaction(InvalidTransaction)
NotIntercepted(NotIntercepted)
Implementations
Sourceimpl IKeylessDeployErrors
impl IKeylessDeployErrors
Sourcepub const SELECTORS: &'static [[u8; 4]]
pub const SELECTORS: &'static [[u8; 4]]
All the selectors of this enum.
Note that the selectors might not be in the same order as the variants. No guarantees are made about the order of the selectors.
Prefer using SolInterface methods instead.
Sourcepub const VARIANT_NAMES: &'static [&'static str]
pub const VARIANT_NAMES: &'static [&'static str]
The names of the variants in the same order as SELECTORS.
Sourcepub const SIGNATURES: &'static [&'static str]
pub const SIGNATURES: &'static [&'static str]
The signatures in the same order as SELECTORS.