pub struct ExecutionReverted {
pub gasUsed: u64,
pub output: Bytes,
}Expand description
@notice The sandbox execution reverted.
@param gasUsed The amount of gas used before reverting.
@param output The revert output data.
Custom error with signature ExecutionReverted(uint64,bytes) and selector 0xad2bd1d9.
error ExecutionReverted(uint64 gasUsed, bytes output);Fields
gasUsed: u64output: BytesTrait Implementations
Sourceimpl Clone for ExecutionReverted
impl Clone for ExecutionReverted
Sourcefn clone(&self) -> ExecutionReverted
fn clone(&self) -> ExecutionReverted
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolError for ExecutionReverted
impl SolError for ExecutionReverted
Sourcetype Parameters<'a> = (Uint<64>, Bytes)
type Parameters<'a> = (Uint<64>, Bytes)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<ExecutionReverted as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<ExecutionReverted as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.