pub struct InsufficientComputeGas {
pub limit: u64,
pub used: u64,
}Expand description
@notice The remaining compute gas is insufficient to pay for the keyless deploy overhead.
@param limit The configured compute gas limit.
@param used The compute gas usage.
Custom error with signature InsufficientComputeGas(uint64,uint64) and selector 0x3961c2b6.
error InsufficientComputeGas(uint64 limit, uint64 used);Fields
limit: u64used: u64Trait Implementations
Sourceimpl Clone for InsufficientComputeGas
impl Clone for InsufficientComputeGas
Sourcefn clone(&self) -> InsufficientComputeGas
fn clone(&self) -> InsufficientComputeGas
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolError for InsufficientComputeGas
impl SolError for InsufficientComputeGas
Sourceconst SIGNATURE: &'static str = "InsufficientComputeGas(uint64,uint64)"
const SIGNATURE: &'static str = "InsufficientComputeGas(uint64,uint64)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (Uint<64>, Uint<64>)
type Parameters<'a> = (Uint<64>, Uint<64>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<InsufficientComputeGas as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<InsufficientComputeGas as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.