pub struct remainingComputeGasCall;Expand description
@notice Returns remaining compute gas of the current call.
@dev In Rex4+, returns the caller’s per-frame remaining compute gas (not the 98/100 forwarded child budget).
@dev For direct TX calls with no active frame, returns TX compute limit minus intrinsic compute gas.
@dev In pre-Rex4, this falls back to transaction-level remaining compute gas.
@return remaining The remaining compute gas of the current call.
Function with signature remainingComputeGas() and selector 0x02be4d84.
function remainingComputeGas() external view returns (uint64 remaining);Trait Implementations
Sourceimpl Clone for remainingComputeGasCall
impl Clone for remainingComputeGasCall
Sourcefn clone(&self) -> remainingComputeGasCall
fn clone(&self) -> remainingComputeGasCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl SolCall for remainingComputeGasCall
impl SolCall for remainingComputeGasCall
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<remainingComputeGasCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<remainingComputeGasCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype ReturnTuple<'a> = (Uint<64>,)
type ReturnTuple<'a> = (Uint<64>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<remainingComputeGasCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<remainingComputeGasCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.