pub struct remainingComputeGasReturn {
pub remaining: u64,
}Expand description
@notice Returns remaining compute gas of the current call.
@dev In Rex4+, returns the caller’s per-frame remaining compute gas (not the 98/100 forwarded child budget).
@dev For direct TX calls with no active frame, returns TX compute limit minus intrinsic compute gas.
@dev In pre-Rex4, this falls back to transaction-level remaining compute gas.
@return remaining The remaining compute gas of the current call.
Container type for the return parameters of the remainingComputeGas() function.
Fields
remaining: u64Trait Implementations
Sourceimpl Clone for remainingComputeGasReturn
impl Clone for remainingComputeGasReturn
Sourcefn clone(&self) -> remainingComputeGasReturn
fn clone(&self) -> remainingComputeGasReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for remainingComputeGasReturn
impl RefUnwindSafe for remainingComputeGasReturn
impl Send for remainingComputeGasReturn
impl Sync for remainingComputeGasReturn
impl Unpin for remainingComputeGasReturn
impl UnsafeUnpin for remainingComputeGasReturn
impl UnwindSafe for remainingComputeGasReturn