pub struct emitLogReturn {}Expand description
@notice Emits a single log entry with the given topic and data.
@param topic A bytes32 topic identifier for the log.
@param data Arbitrary data payload for the log.
Container type for the return parameters of the emitLog(bytes32,bytes) function.