pub struct getSlotsReturn {
pub values: Vec<FixedBytes<32>>,
}Expand description
@notice Reads multiple storage slots in a single call.
@param slots Array of slot numbers to read.
@return values Array of 32-byte values stored at each slot.
Container type for the return parameters of the getSlots(uint256[]) function.
Fields
values: Vec<FixedBytes<32>>Trait Implementations
Sourceimpl Clone for getSlotsReturn
impl Clone for getSlotsReturn
Sourcefn clone(&self) -> getSlotsReturn
fn clone(&self) -> getSlotsReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for getSlotsReturn
impl RefUnwindSafe for getSlotsReturn
impl Send for getSlotsReturn
impl Sync for getSlotsReturn
impl Unpin for getSlotsReturn
impl UnsafeUnpin for getSlotsReturn
impl UnwindSafe for getSlotsReturn