pub struct multiCallReturn {
pub results: Vec<Bytes>,
}Expand description
@notice Executes multiple calls in a single transaction.
@param data Array of encoded function calls to execute.
@return results Array of return values from each call.
Container type for the return parameters of the multiCall(bytes[]) function.
Fields
results: Vec<Bytes>Trait Implementations
Sourceimpl Clone for multiCallReturn
impl Clone for multiCallReturn
Sourcefn clone(&self) -> multiCallReturn
fn clone(&self) -> multiCallReturn
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreAuto Trait Implementations
impl Freeze for multiCallReturn
impl RefUnwindSafe for multiCallReturn
impl Send for multiCallReturn
impl Sync for multiCallReturn
impl Unpin for multiCallReturn
impl UnsafeUnpin for multiCallReturn
impl UnwindSafe for multiCallReturn