pub struct sendHintReturn {}Expand description
@notice Sends a hint to the oracle service backend.
@dev This is a view function that doesn’t modify state but is intercepted by the EVM
to forward hints to the oracle service. Available from Rex2 hardfork.
@param topic A bytes32 topic identifier for the hint.
@param data Arbitrary data payload for the hint.
Container type for the return parameters of the sendHint(bytes32,bytes) function.