pub struct setSlotReturn {}Expand description
@notice Writes a value to a single storage slot.
@param slot The slot number to write to.
@param value The 32-byte value to store.
Container type for the return parameters of the setSlot(uint256,bytes32) function.