pub struct setSlotsReturn {}Expand description
@notice Writes values to multiple storage slots in a single call.
@param slots Array of slot numbers to write to.
@param values Array of 32-byte values to store at each slot.
Container type for the return parameters of the setSlots(uint256[],bytes32[]) function.