pub struct scheduleNextSystemAddressChangeCall {
pub newSystemAddress: Address,
pub activationBlock: U256,
}Expand description
@notice Schedules a system address change.
Function with signature scheduleNextSystemAddressChange(address,uint256) and selector 0x3411f3c3.
function scheduleNextSystemAddressChange(address newSystemAddress, uint256 activationBlock) external;Fields
newSystemAddress: AddressactivationBlock: U256Trait Implementations
Sourceimpl Clone for scheduleNextSystemAddressChangeCall
impl Clone for scheduleNextSystemAddressChangeCall
Sourcefn clone(&self) -> scheduleNextSystemAddressChangeCall
fn clone(&self) -> scheduleNextSystemAddressChangeCall
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for scheduleNextSystemAddressChangeCall
impl Default for scheduleNextSystemAddressChangeCall
Sourcefn default() -> scheduleNextSystemAddressChangeCall
fn default() -> scheduleNextSystemAddressChangeCall
Returns the “default value” for a type. Read more
impl Eq for scheduleNextSystemAddressChangeCall
Sourceimpl SolCall for scheduleNextSystemAddressChangeCall
impl SolCall for scheduleNextSystemAddressChangeCall
Sourceconst SIGNATURE: &'static str = "scheduleNextSystemAddressChange(address,uint256)"
const SIGNATURE: &'static str = "scheduleNextSystemAddressChange(address,uint256)"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<256>)
type Parameters<'a> = (Address, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<scheduleNextSystemAddressChangeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<scheduleNextSystemAddressChangeCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = scheduleNextSystemAddressChangeReturn
type Return = scheduleNextSystemAddressChangeReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<scheduleNextSystemAddressChangeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<scheduleNextSystemAddressChangeCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl StructuralPartialEq for scheduleNextSystemAddressChangeCall