System contracts for the MegaETH EVM.
This crate provides bytecode constants for system contracts used by mega-evm. When building from the repository with Foundry installed, the build script validates that the pre-generated constants match the compiled Solidity source. When building from a published crate (without Foundry), the pre-generated constants are used directly.
Re-exports
pub use alloy_primitives;
Modules
- access_
control MegaAccessControlcontract bytecode and interface.- keyless_
deploy KeylessDeploycontract bytecode and interface.- limit_
control MegaLimitControlcontract bytecode and interface.- oracle
- Oracle contract bytecode and interface.
- sequencer_
registry SequencerRegistrycontract bytecode and interface.